summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabberclient.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jabberclient.cpp')
-rw-r--r--kopete/protocols/jabber/jabberclient.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/protocols/jabber/jabberclient.cpp b/kopete/protocols/jabber/jabberclient.cpp
index fddd588f..ef90323c 100644
--- a/kopete/protocols/jabber/jabberclient.cpp
+++ b/kopete/protocols/jabber/jabberclient.cpp
@@ -61,8 +61,8 @@ public:
XMPP::Client *jabberClient;
XMPP::ClientStream *jabberClientStream;
JabberConnector *jabberClientConnector;
- QCA::TLS *jabberTLS;
- XMPP::QCATLSHandler *jabberTLSHandler;
+ TQCA::TLS *jabberTLS;
+ XMPP::TQCATLSHandler *jabberTLSHandler;
// ignore TLS warnings
bool ignoreTLSWarnings;
@@ -603,7 +603,7 @@ JabberClient::ErrorCode JabberClient::connect ( const XMPP::Jid &jid, const TQSt
/*
* Return an error if we should force TLS but it's not available.
*/
- if ( ( forceTLS () || useSSL () || probeSSL () ) && !QCA::isSupported ( QCA::CAP_TLS ) )
+ if ( ( forceTLS () || useSSL () || probeSSL () ) && !TQCA::isSupported ( TQCA::CAP_TLS ) )
{
return NoTLS;
}
@@ -631,17 +631,17 @@ JabberClient::ErrorCode JabberClient::connect ( const XMPP::Jid &jid, const TQSt
/*
* Setup authentication layer
*/
- if ( QCA::isSupported ( QCA::CAP_TLS ) )
+ if ( TQCA::isSupported ( TQCA::CAP_TLS ) )
{
- d->jabberTLS = new QCA::TLS;
- d->jabberTLSHandler = new XMPP::QCATLSHandler ( d->jabberTLS );
+ d->jabberTLS = new TQCA::TLS;
+ d->jabberTLSHandler = new XMPP::TQCATLSHandler ( d->jabberTLS );
{
using namespace XMPP;
TQObject::connect ( d->jabberTLSHandler, TQT_SIGNAL ( tlsHandshaken() ), this, TQT_SLOT ( slotTLSHandshaken () ) );
}
- TQPtrList<QCA::Cert> certStore;
+ TQPtrList<TQCA::Cert> certStore;
d->jabberTLS->setCertificateStore ( certStore );
}
@@ -893,10 +893,10 @@ void JabberClient::slotTLSHandshaken ()
emit debugMessage ( "TLS handshake done, testing certificate validity..." );
// FIXME: in the future, this should be handled by KDE, not QCA
int validityResult = d->jabberTLS->certificateValidityResult ();
- if ( validityResult == QCA::TLS::Valid )
+ if ( validityResult == TQCA::TLS::Valid )
{
emit debugMessage ( "Certificate is valid, continuing." );
@@ -893,10 +893,10 @@ void JabberClient::slotTLSHandshaken ()
emit debugMessage ( "TLS handshake done, testing certificate validity..." );
- // FIXME: in the future, this should be handled by KDE, not QCA
+ // FIXME: in the future, this should be handled by KDE, not TQCA
int validityResult = d->jabberTLS->certificateValidityResult ();